---
name: Question
about: Ask a question about Solcore and it’s use
title: ''
labels: question
assignees: ''

---

**Please, confirm the following:**

- [ ] I have checked [Solcore’s documentation](http://docs.solcore.solar/en/master/) and could not find the answer.
- [ ] I haven’t found any [other issue](https://github.com/qpv-research-group/solcore5/issues?q=) on a related topic.

**What’s the question?**
Please, be concise and straight to the point

**Additional information**
Add any other relevant information that could help us answering your question, E.g.:
- Code of a minimum working example showing what you’re trying to do.
- Screenshot showing the problem you are talking about.
- Context in which your question applies
